==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ToolActionRadioInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionRadioInfoDescription } from "./ToolActionRadioInfoDescription";
/**
 * @hidden
 */
export let ToolActionRadioInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionRadioInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionRadioInfoDescriptionMetadata.a == null) {
                ToolActionRadioInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionRadioInfoDescriptionMetadata.c(ToolActionRadioInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionRadioInfoDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolActionRadioInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
            a.item("IsChecked", "Boolean");
            a.item("Channel", "String");
        }
        static d(a) {
            ToolActionRadioInfoDescriptionMetadata.b(a);
            a.ad("ToolActionRadioInfo", () => new ToolActionRadioInfoDescription());
            a.ac("ToolActionRadioInfo", ToolActionRadioInfoDescriptionMetadata.a);
        }
    }
    ToolActionRadioInfoDescriptionMetadata.$t = markType(ToolActionRadioInfoDescriptionMetadata, 'ToolActionRadioInfoDescriptionMetadata');
    ToolActionRadioInfoDescriptionMetadata.a = null;
    return ToolActionRadioInfoDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ToolActionRadioInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionRadioInfoDescription } from "./ToolActionRadioInfoDescription";
/**
 * @hidden
 */
export let ToolActionRadioInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionRadioInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionRadioInfoDescriptionMetadata.a == null) {
                ToolActionRadioInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionRadioInfoDescriptionMetadata.c(ToolActionRadioInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionRadioInfoDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionRadioInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
            a.item("IsChecked", "Boolean");
            a.item("Channel", "String");
        }
        static d(a) {
            ToolActionRadioInfoDescriptionMetadata.b(a);
            a.ae("ToolActionRadioInfo", () => new ToolActionRadioInfoDescription());
            a.ad("ToolActionRadioInfo", ToolActionRadioInfoDescriptionMetadata.a);
        }
    }
    ToolActionRadioInfoDescriptionMetadata.$t = markType(ToolActionRadioInfoDescriptionMetadata, 'ToolActionRadioInfoDescriptionMetadata');
    ToolActionRadioInfoDescriptionMetadata.a = null;
    return ToolActionRadioInfoDescriptionMetadata;
})();
